@@ -9,7 +9,7 @@ if (getRversion() >= "3.5.0")
 function(...) {
 
   packageStartupMessage("\n",
-      "lessR 4.0.8  feedback: gerbing@pdx.edu  web: lessRstats.com/new\n",
+      "lessR 4.1.3  feedback: gerbing@pdx.edu  web: lessRstats.com/new\n",
       "---------------------------------------------------------------\n",
       "> d <- Read(\"\")   Read text, Excel, SPSS, SAS, or R data file\n",
       "  d is default data frame, data= in analysis routines optional\n",
@@ -260,8 +260,10 @@ function(...) {
 
   date_num <- as.numeric(time(y))
   year <- floor(date_num)
-  year_beg <- as.POSIXct(paste0(year, '-01-01'))
-  year_end <- as.POSIXct(paste0(year+1, '-01-01'))
+# year_beg <- as.POSIXct(paste0(year, '-01-01'))  # not work for "1986-01-01"
+  year_beg <- as.POSIXlt.character(paste0(year, '-01-01 01:01:01'))
+# year_end <- as.POSIXct(paste0(year+1, '-01-01'))
+  year_end <- as.POSIXlt.character(paste0(year+1, '-01-01 01:01:01'))
   diff.yr <- year_end - year_beg
   dates <- year_beg + ((date_num %% 1) * diff.yr)
   dates <- as.Date(format(dates, format='%Y-%m-%d')) # from POSIX to Date
@@ -335,9 +337,6 @@ function(...) {
     # var.name is a character string, so convert to an object
     if (!is.function(eval(parse(text=var.name)))) {
       in.global <- TRUE
-#      if (!quiet)  # only want to do this if var.name is in a df also
-#        cat(">>> Note:", var.name, "from the workspace, not in",
-#            "a data frame (table)\n")
     }
   }
 
@@ -507,8 +506,7 @@ function(...) {
     
     if (length(.getdfs()) > 0) {  # if not data frame, no point to message
       if (in.global[i] && !quiet)
-         cat(">>> Note:", var.nm[i], "is from the workspace, not in",
-         "a data frame (table)\n")
+         cat(">>> Note:", var.nm[i], "is not in a data frame (table)\n")
       else
         if (any(in.global) && !quiet)
           cat(">>> Note:", var.nm[i], "is NOT in the workspace\n")
@@ -517,9 +515,9 @@ function(...) {
   
   if (any(in.global) && !all(in.global)) {  # eval $ in .xcheck
     cat("\n"); stop(call.=FALSE, "\n","------\n",
-      "Some variables are in the user workspace,\n",
+      "Some variables are in a data frame,\n",
       "  and other variables are not. All must exist and\n",
-      "  be in the workspace or in a data frame, not both.\n\n")
+      "  be in a data frame or not.\n\n")
   }
   
   in.global <- ifelse (all(in.global), TRUE, FALSE)
@@ -782,13 +780,8 @@ function(...) {
 
   tx[length(tx)+1] <- txt1
   if (!isnullby) {
-    #if (is.null(y.lbl))
-      #tx[length(tx)+1] <- "  - by levels of - \n"
-    #else
     tx[length(tx)+1] <- "\n  - by levels of - \n"
     tx[length(tx)] <- paste(tx[length(tx)], txt2, sep="")  # no leading blank
-    #if (is.null(y.lbl))
-      #tx[length(tx)+1] <- .dash2(max(nchar(txt1),nchar(txt2)))
   }
 
   return(tx)
@@ -810,7 +803,7 @@ function(...) {
     marg.y <- par("mai")[1] + par("mai")[3]
     axis_y <- fig.ht - marg.y
     cut.x <- 0.90 * axis_x
-    cut.y <- 0.95 * axis_y
+    cut.y <- 1.10 * axis_y  # multiplier empirically derived
   }
   else {  # do not open a graphics window if no plot
     cut.x <- 3.75
@@ -1297,7 +1290,7 @@ function(dir, axT) {
     workdir <- "top level (root) of your file system"
   else
     workdir <- getwd()
-  cat("The", txt, "written at the current working directory\n")
+  cat("\nThe", txt, "written at the current working directory\n")
   cat("       ", fname, " in:  ", workdir, "\n")
   cat("\n")
 }
@@ -1312,7 +1305,7 @@ function(dir, axT) {
   tx <- character(length = 0)
 
   txt.wrt <- "written at the current working directory." 
-  tx[length(tx)+1] <- paste("The", txt, txt.wrt)
+  tx[length(tx)+1] <- paste("\nThe", txt, txt.wrt)
   tx[length(tx)+1] <- paste("       ", fname, " in:  ", workdir)
 
   return(tx)
@@ -1566,8 +1559,8 @@ function(dir, axT) {
 }
 
 
-# from the theme, get the name of the corresponding pre-set color range 
-.get_fill <- function(theme=getOption("theme"), seq.pal=TRUE) {
+# from the theme, get the sequential or hues palette name for each color theme 
+.get_fill <- function(theme=getOption("theme"), seq.pal=FALSE) {
 
   # for ordinal variables, or color theme not default, get sequential palette
   # for not ordinal and default color theme, qualitative palette
@@ -1575,7 +1568,7 @@ function(dir, axT) {
     if (seq.pal)
       clrs <- "blues"
     else
-      clrs <- getOption("bar_fill_discrete")
+      clrs <- "hues"
   }
   else if (theme %in% c("gray", "white")) clrs <- "grays"
   else if (theme %in% c("lightbronze", "dodgerblue", "blue")) clrs <- "blues"
@@ -1593,6 +1586,7 @@ function(dir, axT) {
 
 # from a pre-defined color palette name, generate the palette
 # if not a palette name, then return the name, i.e., do nothing
+# typically used to convert color name from get_fill() to a color
 .color_range <- function(fill, n.clr) {
 
   # names of color palettes generated by getColors
@@ -1602,7 +1596,7 @@ function(dir, axT) {
   nmR <- c("rainbow", "heat", "terrain")
   nmV<- c("viridis", "cividis", "magma", "inferno", "plasma")
   nmD<- c("distinct")
-  nmW<- c("BottleRocket1", "BottleRocket2", "Rushmore1", "Rushmore",
+  nmW<- c("BottleRocket1", "BottleRocket2", "Rushmore1",
           "Royal1", "Royal2", "Zissou1", "Darjeeling1", "Darjeeling2",
           "Chevalier1", "FantasticFox1", "Moonrise1", "Moonrise2",
           "Moonrise3", "Cavalcanti1", "GrandBudapest1", "GrandBudapest2",
@@ -1680,6 +1674,11 @@ function(dir, axT) {
   }
 
   else {  # (count.v) so do viridis scaling
+    if (!requireNamespace("viridisLite", quietly=TRUE)) {
+      stop("Package \"viridisLite\" needed for these colors\n",
+           "Please install it:  install.packages(\"viridisLite\")\n\n",
+           call. = FALSE)
+    }
     vir <- viridisLite::viridis(100)
     x.nrm <- x / max(x)
     cc <- double(length=length(x.nrm))
@@ -1734,6 +1733,7 @@ function(dir, axT) {
 
 
 # change class call to class character
+# otherwise length > 1, make a single character string
 .fun_call.deparse <- function(fun_call) {
 
   fc.d <- deparse(fun_call)
