@@ -4,6 +4,9 @@ suppressPackageStartupMessages(library("lessR"))
 ## ----read-------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
 
+## ----labels-----------------------------------------------------------------------------------------------------------
+l <- rd("Employee_lbl")
+
 ## ----hsform, dataTable, echo=FALSE, out.width='28%', fig.asp=.7, fig.align='center', out.extra='style="border-style: none"'----
 knitr::include_graphics(system.file("img", "hsExplain.png", package="lessR"))
 
