@@ -73,32 +73,32 @@ Plot(Years, Salary, by=Gender, size=2, fit="lm",
      color=c("darkgreen", "gold4")
 )
 
-## ---- fig.width=4.5, fig.height=4-------------------------------------------------------------------------------------
+## ---- fig.width=7, fig.height=3.5-------------------------------------------------------------------------------------
 Plot(Years, Salary, by1=Gender, fit="lm")
 
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(Salary, Dept)
 
-## ---- figwidth=6, fig.height=2.75-------------------------------------------------------------------------------------
-Plot(Salary, by=Dept)
+## ---- fig.width=5, fig.height=2.75------------------------------------------------------------------------------------
+Plot(Salary, by=Gender)
 
-## ---- figwidth=6, fig.height=4----------------------------------------------------------------------------------------
-Plot(Salary, by1=Dept)
+## ---- fig.width=7, fig.height=2.75------------------------------------------------------------------------------------
+Plot(Salary, by1=Gender)
 
-## ---- fig.height=4----------------------------------------------------------------------------------------------------
-Plot(Salary, by1=Dept, vbs_plot="vs")
+## ---- fig.width=7, fig.height=2.75------------------------------------------------------------------------------------
+Plot(Salary, by1=Gender, vbs_plot="vs")
 
-## ---- figwidth=6------------------------------------------------------------------------------------------------------
+## ---- fig.width=7, fig.height=2.75------------------------------------------------------------------------------------
 BoxPlot(Salary, by1=Gender, vbs_mean=TRUE, box_fill="lightgoldenrod")
 
-## ---- figwidth=6------------------------------------------------------------------------------------------------------
+## ---- fig.width=6-----------------------------------------------------------------------------------------------------
 Plot(Salary, Dept, by=Gender)
 
-## ---- fig.width=6, fig.height=7---------------------------------------------------------------------------------------
-Plot(Salary, by1=Gender, by2=Dept)
+## ---- fig.width=5, fig.height=7---------------------------------------------------------------------------------------
+Plot(Salary, by1=Gender, by2=Dept, n_col=1)
 
-## ---- fig.width=6, fig.height=4---------------------------------------------------------------------------------------
-Plot(Salary, by1=Dept, by=Gender)
+## ---- fig.width=5, fig.height=5---------------------------------------------------------------------------------------
+Plot(Salary, by1=Dept, by=Gender, n_col=1)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 d <- Read("Cars93")
@@ -108,13 +108,13 @@ d$Transmission <- factor(d$Manual, levels=0:1, labels=c("Auto", "Manual"))
 d$Source <- factor(d$Source, levels=0:1, labels=c("Foreign", "Domestic"))
 
 ## ---- fig.height=7, fig.width=6---------------------------------------------------------------------------------------
-Plot(Weight, MPGcity, by1=Cylinders, by2=Transmission, by=Source)
+Plot(Weight, MPGcity, by1=Cylinders, by2=Transmission, by=Source, n_col=1)
 
 ## ---- fig.height=3----------------------------------------------------------------------------------------------------
 d <- Read("Employee", quiet=TRUE)
 Plot(Dept, Gender)
 
-## ---- fig.height=4, fig.width=6---------------------------------------------------------------------------------------
+## ---- fig.height=3.5, fig.width=6-------------------------------------------------------------------------------------
 Plot(Dept, Gender, radius=.6, power=0.8, pad_x=0.05, pad_y=0.05)
 
 ## ---- fig.height=3----------------------------------------------------------------------------------------------------
